# -*- coding: utf-8 -*-
# Copyright (C) 2014-2022  EDF R&D
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
#
# See http://www.salome-platform.org/ or email : webmaster.salome@opencascade.com
#
"""compoundFromList"""

import logging
from .geomsmesh import geompy
from .geomsmesh import geomPublish
from . import initLog

def compoundFromList(elements, nom=None):
  """compoundFromList"""

  logging.debug('start')

  l_shapes = list()
  for elem in elements:
    if not isinstance(elem, list):
      l_shapes.append(elem)
    else:
      if elem[0] is not None:
        l_shapes.append(elem[0])

  if nom is not None:
    for indice, elem in enumerate(l_shapes):
      nomi = nom +"%d"%indice
      logging.debug('nom: %s',nomi)
      geomPublish(initLog.debug, elem, nomi)

  shapeCompound = None
  if l_shapes:
    shapeCompound = geompy.MakeCompound(l_shapes)
    nomc = "compound_%s"%nom
    geomPublish(initLog.debug, shapeCompound, nomc)

  return shapeCompound
